summaryrefslogtreecommitdiffstats
path: root/kopete/protocols/winpopup/wpcontact.h
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-16 09:59:34 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-16 09:59:34 -0600
commit83677e35509b4dafac63b76995652bdf3b49f209 (patch)
tree591f1dc22278addb439726c42896376b17bb42bd /kopete/protocols/winpopup/wpcontact.h
parent808e453c56036211f57482ed847d54aca01bba68 (diff)
downloadtdenetwork-83677e35509b4dafac63b76995652bdf3b49f209.tar.gz
tdenetwork-83677e35509b4dafac63b76995652bdf3b49f209.zip
Revert "Rename a number of old tq methods that are no longer tq specific"
This reverts commit 808e453c56036211f57482ed847d54aca01bba68.
Diffstat (limited to 'kopete/protocols/winpopup/wpcontact.h')
-rw-r--r--kopete/protocols/winpopup/wpcontact.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/kopete/protocols/winpopup/wpcontact.h b/kopete/protocols/winpopup/wpcontact.h
index 8acd7235..6843d6c2 100644
--- a/kopete/protocols/winpopup/wpcontact.h
+++ b/kopete/protocols/winpopup/wpcontact.h
@@ -62,7 +62,7 @@ public:
public slots:
virtual void slotUserInfo();
- void slotCheckStatus(); // the call back for the checkStatus timer
+ void slotChecktqStatus(); // the call back for the checktqStatus timer
void slotNewMessage(const TQString &Body, const TQDateTime &Arrival);
private slots:
@@ -73,7 +73,7 @@ private slots:
private:
bool myWasConnected; // true if protocol connected at last check
- TQTimer checkStatus; // checks the status of this contact every second or so
+ TQTimer checktqStatus; // checks the status of this contact every second or so
// KActionCollection *myActionCollection;
// holds all the protocol specific actions (not many!)
Kopete::ChatSession *m_manager;